@@ -1,5 +1,5 @@
 /*********************************************************
- * Copyright (C) 1998-2021 VMware, Inc. All rights reserved.
+ * Copyright (c) 1998-2023 VMware, Inc. All rights reserved.
  *
  * This program is free software; you can redistribute it and/or modify it
  * under the terms of the GNU Lesser General Public License as published
@@ -1589,6 +1589,20 @@ TOOLS_VERSION_UINT_TO_COMPONENTS(const ToolsVersion toolsVersion,   // IN
 #define   TOOLS_VERSION_JACKHAMMER_PATCH11_V_MNR  3
 #define   TOOLS_VERSION_JACKHAMMER_PATCH11_V_BASE 24
 
+#ifndef RC_INVOKED
+#define   TOOLS_VERSION_JACKHAMMER_PATCH12 TOOLS_VERSION_TO_UINT(TOOLS_VERSION_JACKHAMMER_PATCH12_V)
+#endif /* RC_INVOKED */
+#define   TOOLS_VERSION_JACKHAMMER_PATCH12_V_MJR  10
+#define   TOOLS_VERSION_JACKHAMMER_PATCH12_V_MNR  3
+#define   TOOLS_VERSION_JACKHAMMER_PATCH12_V_BASE 25
+
+#ifndef RC_INVOKED
+#define   TOOLS_VERSION_JACKHAMMER_PATCH13 TOOLS_VERSION_TO_UINT(TOOLS_VERSION_JACKHAMMER_PATCH13_V)
+#endif /* RC_INVOKED */
+#define   TOOLS_VERSION_JACKHAMMER_PATCH13_V_MJR  10
+#define   TOOLS_VERSION_JACKHAMMER_PATCH13_V_MNR  3
+#define   TOOLS_VERSION_JACKHAMMER_PATCH13_V_BASE 26
+
 #ifndef RC_INVOKED
 #define   TOOLS_VERSION_SLEDGEHAMMER_RELEASE TOOLS_VERSION_TO_UINT(TOOLS_VERSION_SLEDGEHAMMER_RELEASE_V)
 #endif /* RC_INVOKED */
@@ -1687,10 +1701,58 @@ TOOLS_VERSION_UINT_TO_COMPONENTS(const ToolsVersion toolsVersion,   // IN
 #define   TOOLS_VERSION_JIGSAW_UPDATE1_V_MNR  3
 #define   TOOLS_VERSION_JIGSAW_UPDATE1_V_BASE 5
 
+#ifndef RC_INVOKED
+#define   TOOLS_VERSION_SABRE_SAW_RELEASE TOOLS_VERSION_TO_UINT(TOOLS_VERSION_SABRE_SAW_RELEASE_V)
+#endif /* RC_INVOKED */
+#define   TOOLS_VERSION_SABRE_SAW_RELEASE_V_MJR  12
+#define   TOOLS_VERSION_SABRE_SAW_RELEASE_V_MNR  0
+#define   TOOLS_VERSION_SABRE_SAW_RELEASE_V_BASE 0
 
-#define   TOOLS_VERSION_CURRENT        TOOLS_VERSION_JIGSAW_UPDATE1
-#define   TOOLS_VERSION_CURRENT_STR    TOOLS_VERSION_TO_STR(TOOLS_VERSION_JIGSAW_UPDATE1)
-#define   TOOLS_VERSION_CURRENT_CSV    TOOLS_VERSION_TO_CSV(TOOLS_VERSION_JIGSAW_UPDATE1)
+#ifndef RC_INVOKED
+#define   TOOLS_VERSION_SABRE_SAW_UPDATE1 TOOLS_VERSION_TO_UINT(TOOLS_VERSION_SABRE_SAW_UPDATE1_V)
+#endif /* RC_INVOKED */
+#define   TOOLS_VERSION_SABRE_SAW_UPDATE1_V_MJR  12
+#define   TOOLS_VERSION_SABRE_SAW_UPDATE1_V_MNR  0
+#define   TOOLS_VERSION_SABRE_SAW_UPDATE1_V_BASE 5
+
+#ifndef RC_INVOKED
+#define   TOOLS_VERSION_SABRE_SAW_PATCH1 TOOLS_VERSION_TO_UINT(TOOLS_VERSION_SABRE_SAW_PATCH1_V)
+#endif /* RC_INVOKED */
+#define   TOOLS_VERSION_SABRE_SAW_PATCH1_V_MJR  12
+#define   TOOLS_VERSION_SABRE_SAW_PATCH1_V_MNR  0
+#define   TOOLS_VERSION_SABRE_SAW_PATCH1_V_BASE 6
+
+#ifndef RC_INVOKED
+#define   TOOLS_VERSION_MITER_SAW_RELEASE TOOLS_VERSION_TO_UINT(TOOLS_VERSION_MITER_SAW_RELEASE_V)
+#endif /* RC_INVOKED */
+#define   TOOLS_VERSION_MITER_SAW_RELEASE_V_MJR  12
+#define   TOOLS_VERSION_MITER_SAW_RELEASE_V_MNR  1
+#define   TOOLS_VERSION_MITER_SAW_RELEASE_V_BASE 0
+
+#ifndef RC_INVOKED
+#define   TOOLS_VERSION_MITER_SAW_UPDATE1 TOOLS_VERSION_TO_UINT(TOOLS_VERSION_MITER_SAW_UPDATE1_V)
+#endif /* RC_INVOKED */
+#define   TOOLS_VERSION_MITER_SAW_UPDATE1_V_MJR  12
+#define   TOOLS_VERSION_MITER_SAW_UPDATE1_V_MNR  1
+#define   TOOLS_VERSION_MITER_SAW_UPDATE1_V_BASE 5
+
+#ifndef RC_INVOKED
+#define   TOOLS_VERSION_BANDSAW_RELEASE TOOLS_VERSION_TO_UINT(TOOLS_VERSION_BANDSAW_RELEASE_V)
+#endif /* RC_INVOKED */
+#define   TOOLS_VERSION_BANDSAW_RELEASE_V_MJR  12
+#define   TOOLS_VERSION_BANDSAW_RELEASE_V_MNR  2
+#define   TOOLS_VERSION_BANDSAW_RELEASE_V_BASE 0
+
+#ifndef RC_INVOKED
+#define   TOOLS_VERSION_BANDSAW_UPDATE1 TOOLS_VERSION_TO_UINT(TOOLS_VERSION_BANDSAW_UPDATE1_V)
+#endif /* RC_INVOKED */
+#define   TOOLS_VERSION_BANDSAW_UPDATE1_V_MJR  12
+#define   TOOLS_VERSION_BANDSAW_UPDATE1_V_MNR  2
+#define   TOOLS_VERSION_BANDSAW_UPDATE1_V_BASE 5
+
+#define   TOOLS_VERSION_CURRENT        TOOLS_VERSION_BANDSAW_UPDATE1
+#define   TOOLS_VERSION_CURRENT_STR    TOOLS_VERSION_TO_STR(TOOLS_VERSION_BANDSAW_UPDATE1)
+#define   TOOLS_VERSION_CURRENT_CSV    TOOLS_VERSION_TO_CSV(TOOLS_VERSION_BANDSAW_UPDATE1)
 
 /*
  * The extended Tools version is the current Tools version with the
